﻿using UnityEngine;
using System.Collections;
using UnityEngine.UI;

public class GameplayController : MonoBehaviour {

	public static GameplayController instance;
	public int targetTotal;
	public int timeSpent;
	public int powerUsed = 0;
	public bool isDead = false;
	public bool isPaused = false;

	[SerializeField]
	private Text targetText, causeOfDeathText, timeText, powerUsedText;
	[SerializeField]
	private Text gameOverScoreText, victoryScoreText;
	[SerializeField]
	private GameObject pausePanel;
	[SerializeField]
	private GameObject gameOverPanel;
	[SerializeField]
	private GameObject victoryPanel;


	void Awake () {
		MakeInstance ();
		targetTotal = GetTargetCount ();
		SetTargetCount (0, targetTotal);
		SetPowerUsed (0);
	}

	void Update () {
		if (!isDead) {
			if (Input.GetKeyDown (KeyCode.Escape)) {
				if (!isPaused) {
					PauseGame ();
				} else {
					ResumeGame ();
				}
			}
		}
	}

	void FixedUpdate () {
		timeSpent = Mathf.RoundToInt(Time.timeSinceLevelLoad);
		SetTimeSpent (timeSpent);
	}

	void MakeInstance () {
		if (instance == null) {
			instance = this;
		}
	}

	public void SetPowerUsed (float power) {
		powerUsed = powerUsed + Mathf.RoundToInt (power);
		powerUsedText.text = "Power Used: " + Mathf.RoundToInt (powerUsed);
	}

	public void SetTimeSpent (int timeSpent) {
		int sec = timeSpent % 60;
		float min = Mathf.Floor (timeSpent / 60);
		timeText.text = "Time: " + min + ":" + sec;
	}

	public int GetTargetCount () {
		return GameObject.FindGameObjectsWithTag ("Target").Length;
	}

	public void SetTargetCount (int targetCount, int targetTotal) {
		targetText.text = targetCount + "/" + targetTotal;
		if (targetCount == targetTotal) {
			Victory ();
		}
	}

	public void PauseGame () {
		Time.timeScale = 0f;
		pausePanel.SetActive (true);
		isPaused = true;
	}

	public void ResumeGame () {
		Time.timeScale = 1f;
		pausePanel.SetActive (false);
		isPaused = false;
	}

	public void RestartGame () {
		Time.timeScale = 1f;
		Application.LoadLevel ("Level_1");
	}

	public void GoToMenu () {
		Time.timeScale = 1f;
		Application.LoadLevel ("MainMenu");
	}

	public void GameOver (int cause,float reason) {
		isDead = true;
		Time.timeScale = 0f;
		gameOverPanel.SetActive (true);

		int sec = timeSpent % 60;
		float min = Mathf.Floor (timeSpent / 60);

		gameOverScoreText.text = "Time: " + min + ":" + sec + "\nPower Used: " + powerUsed;
		if (cause == 0) {
			causeOfDeathText.text = "Crashing into the Earth at a breakneck speed of " + Mathf.RoundToInt (reason * 5) + "mph\nouch...";
		}
	}

	public void Victory () {
		Time.timeScale = 0f;
		victoryPanel.SetActive (true);

		int sec = timeSpent % 60;
		float min = Mathf.Floor (timeSpent / 60);
		victoryScoreText.text = "Time: " + min + ":" + sec + "\nPower Used: " + powerUsed;
	}

}
