﻿using UnityEngine;
using System.Collections;

public class GunScript : MonoBehaviour {

	public float gunAngle;
	public float dist = 1.5f;
	public bool didShoot;
	public bool canShoot;
	public bool shot = false;

	[SerializeField]
	private Transform myTransParent;
	[SerializeField]
	private Transform myTransChild;
	[SerializeField]
	private GameObject bullet;
	[SerializeField]
	private PlayerScript pscript;
	private Animator anim;

	void Awake () {
		InitiateVariables ();
	}

	void Update () {
		bool isDead = GameplayController.instance.isDead;
		bool isPaused = GameplayController.instance.isPaused;
		if (!isDead) {
			if (!isPaused) {
				if (Input.GetButtonDown ("Fire1")) {
					shot = true;
				}
			}
		}
	}

	void FixedUpdate () {
		Vector2 scale = myTransParent.localScale;
		RotateGun (scale.x);
		Shoot (scale.x);
	}

	void InitiateVariables () {
		anim = GetComponent<Animator> ();
	}

	void RotateGun (float scale) {
		Vector2 temp = Camera.main.ScreenToWorldPoint (Input.mousePosition) - transform.position;
		temp.Normalize ();
		gunAngle = Mathf.Atan2 (temp.y, temp.x) * Mathf.Rad2Deg;

		if (scale > 0) {
			transform.rotation = Quaternion.Euler (0, 0, gunAngle);
		} else {
			transform.rotation = Quaternion.Euler (0, 0, 180 - gunAngle);
		}
	}

	void Shoot (float scale) {
		didShoot = pscript.didShoot;
		if (shot) {
			canShoot = pscript.canShoot;
			if (canShoot) {
				
				if (scale > 0) {
					Instantiate (bullet, myTransChild.position, myTransChild.rotation);
					StartCoroutine (Fire ());
				} else {
					Quaternion bulletRotation = Quaternion.Euler (new Vector3 (0, 0, gunAngle));
					Instantiate (bullet, myTransChild.position, bulletRotation);
					StartCoroutine (Fire ());
				}
			
				didShoot = true;
			}
			shot = false;
		}
	}

	IEnumerator Fire () {
		anim.SetBool ("Fire", true);
		yield return new WaitForSeconds (0.5f);
		anim.SetBool ("Fire", false);
	}

}
