﻿using UnityEngine;
using System.Collections;
using UnityEngine.UI;

public class PlayerScript : MonoBehaviour {

	public float moveForce = 20f, jumpForce = 300f, rocketJumpForce = 600f, maxVelocity = 4f, deadVelocity = 3.8f;
	public float rocketJumpForceMax = 800f, rocketJumpForceMin = 300f;
	public float powerMeterMax = 100f, powerMeter = 50f, rechargeRate = 10f;
	public float jumpCost = 33f, jumpCostMin = 10f, jumpCostMax = 50f;
	public float freq = 20f, amp = 60f, dfreq1 = 100f, damp1 = 10f;
	public float freqMax = 20000f, freqMin = 20f , ampMax = 10f, ampMin = 1f;
	public bool grounded = true, canRocketJump, didShoot, canShoot;
	public bool isMovingPos = false, isMovingNeg = false, isJumping;
	public bool isDead = false, isPaused = false;
	public float relVel;

	private Rigidbody2D myBody;
	private Animator anim;
	[SerializeField]
	private Animator animboost;
	[SerializeField]
	private GunScript gscript;
	[SerializeField]
	private Text waveInfoText;

	void Awake () {
		InitiateVariables ();
	}

	void Start () {
		StartCoroutine (ChargePower ());
	}

	void Update () {
		ChangeFreqAmp ();
		CheckIfJumped ();
		isPaused = GameplayController.instance.isPaused;
	}

	void FixedUpdate () {
		CheckAlive ();
		PlayerWalkKeyboard ();
		CheckPlayerShot ();
		CheckPower ();
		ChangeFreqAmp ();
		UpdateFreqAmp ();
	}

	void CheckAlive () {
		if (isDead) {
			GameplayController.instance.GameOver (0, relVel);
		}
	}

	void CheckPlayerShot () {
		didShoot = gscript.didShoot;
		if (didShoot) {
			didShoot = false;
			powerMeter = powerMeter - jumpCost;
			GameplayController.instance.SetPowerUsed (jumpCost);
		}
	}

	void CheckPower () {
		if (powerMeter < jumpCost) {
			canRocketJump = false;
			canShoot = false;
		} else {
			canRocketJump = true;
			canShoot = true;
		}
	}

	void ChangeFreqAmp () {

		if (!Input.GetKey (KeyCode.LeftShift) && Input.GetKeyDown (KeyCode.Q) && !Input.GetKeyDown (KeyCode.E)) {
			freq = freq - dfreq1;
			if (freq < freqMin) {
				freq = freqMin;
			}
		} else if (!Input.GetKey (KeyCode.LeftShift) && !Input.GetKeyDown (KeyCode.Q) && Input.GetKeyDown (KeyCode.E)) {
			freq = freq + dfreq1;
			if (freq > freqMax) {
				freq = freqMax;
			}
		}

		if (Input.GetKey (KeyCode.LeftShift) && Input.GetKeyDown (KeyCode.Q) && !Input.GetKeyDown (KeyCode.E)) {
			amp = amp - damp1;
			if (amp < ampMin) {
				amp = ampMin;
			}
		} else if (Input.GetKey (KeyCode.LeftShift) && !Input.GetKeyDown (KeyCode.Q) && Input.GetKeyDown (KeyCode.E)) {
			amp = amp + damp1;
			if (amp > ampMax) {
				amp = ampMax;
			}
		}

		waveInfoText.text = freq + "Hz -- " + amp + "dB";
	}

	void UpdateFreqAmp () {
		jumpCost = Mathf.Lerp (jumpCostMin, jumpCostMax, amp / ampMax);
		rocketJumpForce = Mathf.Lerp (rocketJumpForceMin, rocketJumpForceMax, amp / ampMax);
	}

	void PlayerWalkKeyboard () {

		float forceX = 0f;
		float forceY = 0f;
		float vel = Mathf.Abs (myBody.velocity.x);

		float lr = Input.GetAxisRaw ("Horizontal");

		if (lr > 0) {
			if (vel < maxVelocity) {
				isMovingPos = true;
				forceX = moveForce;
			}
			Vector3 scale = transform.localScale;
			scale.x = 1f * Mathf.Abs(scale.x);
			transform.localScale = scale;
			anim.SetBool ("Walk", true);
		} else if (lr < 0) {
			if (vel < maxVelocity) {
				forceX = -moveForce;
			}
			Vector3 scale = transform.localScale;
			scale.x = -1f * Mathf.Abs(scale.x);
			transform.localScale = scale;
			anim.SetBool ("Walk", true);
		} else if (lr == 0) {
			forceX = 0f;
			anim.SetBool ("Walk", false);
		}

		if (isJumping) {
			if (grounded) {
				forceY = jumpForce;
				grounded = false;
				myBody.velocity = new Vector2 (myBody.velocity.x, 0f);
			} else {
				if (canRocketJump) {
					canRocketJump = false;
					powerMeter = powerMeter - jumpCost;
					GameplayController.instance.SetPowerUsed (jumpCost);
					forceY = rocketJumpForce;
					myBody.velocity = new Vector2 (myBody.velocity.x, 0f);
					animboost.SetBool ("IsRocketJump", true);
					StartCoroutine (RocketJump ());
				}
			}
			isJumping = false;
		}

		myBody.AddForce (new Vector2 (forceX, forceY));
	}

	void CheckIfJumped () {
		if (Input.GetKeyDown (KeyCode.Space)) {
			isJumping = true;
		}
	}

	void InitiateVariables () {
		myBody = GetComponent<Rigidbody2D> ();
		anim = GetComponent<Animator> ();
	}

	void OnCollisionEnter2D (Collision2D target) {
		if (target.gameObject.tag == "Ground") {
			relVel = target.relativeVelocity.magnitude;
			if (relVel >= deadVelocity) {
				isDead = true;
			}
			grounded = true;
		}
	}

	IEnumerator ChargePower () {
		if (!isPaused) {
			float start = Time.realtimeSinceStartup;
			while (Time.realtimeSinceStartup < start + 1f / rechargeRate) {
				yield return null;
			}
			powerMeter++;
			if (powerMeter > powerMeterMax) {
				powerMeter = powerMeterMax;
			}
		}
		yield return null;
		StartCoroutine (ChargePower ());
	}

	IEnumerator RocketJump () {
		float start = Time.realtimeSinceStartup;
		while (Time.realtimeSinceStartup < start + 0.3f) {
			yield return null;
		}
		animboost.SetBool ("IsRocketJump", false);
	}



}
