﻿using UnityEngine;
using System.Collections;

public class SoundScript : MonoBehaviour {

	public float speed = 500f;
	public float gunAngle;
	public float amp, ampMax, freq;
	public float disrate = 0.08f;


	[SerializeField]
	private BoxCollider2D collide;
	[SerializeField]
	private BoxCollider2D trigger;

	private Animator anim;
	private Rigidbody2D myBody;
	private Transform myTrans;
	private Transform myTransPlayer;
	private PlayerScript pscript;

	void Awake () {
		InitializeVariables ();
		gunAngle = myTrans.rotation.eulerAngles.z;
		amp = pscript.amp;
		ampMax = pscript.ampMax;
		freq = pscript.freq;
	}

	void Start () {
		Vector2 bulletScale = new Vector2 (1, 1) * Mathf.Lerp (2, 5, amp / ampMax);
		transform.localScale = bulletScale;
		float scale = myTransPlayer.localScale.x;
		if (scale > 0) {
			myBody.velocity = new Vector2 (Mathf.Cos (gunAngle * Mathf.Deg2Rad), Mathf.Sin (gunAngle * Mathf.Deg2Rad)) * speed;
		} else {
			myBody.velocity = new Vector2 (Mathf.Cos ((180 - gunAngle) * Mathf.Deg2Rad), Mathf.Sin ((180 - gunAngle) * Mathf.Deg2Rad)) * speed;
		}
	}

	void FixedUpdate () {
		transform.localScale = new Vector2 (transform.localScale.x - disrate, transform.localScale.y - disrate);
		if (transform.localScale.x < 1) {
			Destroy (gameObject);
		}
	}

	void InitializeVariables () {
		anim = GetComponent<Animator> ();
		myBody = GetComponent<Rigidbody2D> ();
		myTrans = GameObject.FindGameObjectWithTag ("Gun").GetComponent<Transform> ();
		myTransPlayer = GameObject.FindGameObjectWithTag ("Player").GetComponent<Transform> ();
		pscript = GameObject.FindGameObjectWithTag ("Player").GetComponent<PlayerScript> ();
	}

	void OnTriggerEnter2D (Collider2D target) {
		if (freq >= 2500 && freq <= 5500) {
			if (target.tag == "Red Door") {
				collide.enabled = false;
			}
		}

		if (freq >= 12500 && freq <= 17500) {
			if (target.tag == "Blue Door") {
				collide.enabled = false;
			}
		}
	}

	void OnTriggerExit2D (Collider2D target) {
		if (freq >= 2500 && freq <= 5500) {
			if (target.tag == "Red Door") {
				collide.enabled = true;
			}
		}

		if (freq >= 12500 && freq <= 17500) {
			if (target.tag == "Blue Door") {
				collide.enabled = true;
			}
		}
	}

	void OnCollisionEnter2D (Collision2D target) {
		StartCoroutine (SoundHit ());
	}

	IEnumerator SoundHit () {
		anim.SetBool ("Hit", true);
		float start = Time.realtimeSinceStartup;
		while (Time.realtimeSinceStartup < start + 0.3f) {
			yield return null;
		}
		Destroy (gameObject);
	}





}
